==> aws-java-sdk-lightsail-1.11.75-sources.jar: com/amazonaws/services/lightsail/model/GetStaticIpResult.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.lightsail.model;

import java.io.Serializable;

/**
 * 
 * @see <a href="http://docs.aws.amazon.com/goto/WebAPI/lightsail-2016-11-28/GetStaticIp"/>AWS API Documentation</a>
 */
public class GetStaticIpResult extends com.amazonaws.AmazonWebServiceResult<com.amazonaws.ResponseMetadata> implements Serializable, Cloneable {

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     */
    private StaticIp staticIp;

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @param staticIp
     *        An array of key-value pairs containing information about the requested static IP.
     */

    public void setStaticIp(StaticIp staticIp) {
        this.staticIp = staticIp;
    }

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @return An array of key-value pairs containing information about the requested static IP.
     */

    public StaticIp getStaticIp() {
        return this.staticIp;
    }

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @param staticIp
     *        An array of key-value pairs containing information about the requested static IP.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public GetStaticIpResult withStaticIp(StaticIp staticIp) {
        setStaticIp(staticIp);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getStaticIp() != null)
            sb.append("StaticIp: ").append(getStaticIp());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetStaticIpResult == false)
            return false;
        GetStaticIpResult other = (GetStaticIpResult) obj;
        if (other.getStaticIp() == null ^ this.getStaticIp() == null)
            return false;
        if (other.getStaticIp() != null && other.getStaticIp().equals(this.getStaticIp()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getStaticIp() == null) ? 0 : getStaticIp().hashCode());
        return hashCode;
    }

    @Override
    public GetStaticIpResult clone() {
        try {
            return (GetStaticIpResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException("Got a CloneNotSupportedException from Object.clone() " + "even though we're Cloneable!", e);
        }
    }
}

==> aws-java-sdk-lightsail-1.11.76-sources.jar: com/amazonaws/services/lightsail/model/GetStaticIpResult.java <==
/*
 * Copyright 2012-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.lightsail.model;

import java.io.Serializable;

/**
 * 
 * @see <a href="http://docs.aws.amazon.com/goto/WebAPI/lightsail-2016-11-28/GetStaticIp" target="_top">AWS API
 *      Documentation</a>
 */
public class GetStaticIpResult extends com.amazonaws.AmazonWebServiceResult<com.amazonaws.ResponseMetadata> implements Serializable, Cloneable {

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     */
    private StaticIp staticIp;

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @param staticIp
     *        An array of key-value pairs containing information about the requested static IP.
     */

    public void setStaticIp(StaticIp staticIp) {
        this.staticIp = staticIp;
    }

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @return An array of key-value pairs containing information about the requested static IP.
     */

    public StaticIp getStaticIp() {
        return this.staticIp;
    }

    /**
     * <p>
     * An array of key-value pairs containing information about the requested static IP.
     * </p>
     * 
     * @param staticIp
     *        An array of key-value pairs containing information about the requested static IP.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public GetStaticIpResult withStaticIp(StaticIp staticIp) {
        setStaticIp(staticIp);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getStaticIp() != null)
            sb.append("StaticIp: ").append(getStaticIp());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetStaticIpResult == false)
            return false;
        GetStaticIpResult other = (GetStaticIpResult) obj;
        if (other.getStaticIp() == null ^ this.getStaticIp() == null)
            return false;
        if (other.getStaticIp() != null && other.getStaticIp().equals(this.getStaticIp()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getStaticIp() == null) ? 0 : getStaticIp().hashCode());
        return hashCode;
    }

    @Override
    public GetStaticIpResult clone() {
        try {
            return (GetStaticIpResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException("Got a CloneNotSupportedException from Object.clone() " + "even though we're Cloneable!", e);
        }
    }
}
